class LinksController < ApplicationController

  before_filter :login_required , :only => [:new, :create, :edit, :update, :destroy]

  # GET /:username/links
  # GET /:username/links.xml
  def index
    user = User.find_by_login(params[:username])
    @tags = Tag.find_by_user_name(params[:username])
    @links = user.links
    respond_to do |format|
      format.html # index.html.erb
      format.xml  { render :xml => @links }
    end
  end

  # GET /:username/links/1
  # GET /:username/links/1.xml
  def show
    @link = Link.find(params[:id])
    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @link }
    end
  end

  # GET /:username/links/new
  # GET /:username/links/new.xml
  def new
    @link = Link.new
    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @link }
    end
  end

  # GET /:username/links/1/edit
  def edit
    @link = Link.find(params[:id])
  end

  # POST /:username/links
  # POST /:username/links.xml
  def create
    respond_to do |format|
      @link = Link.create_with_user(params[:link], current_user)
      if @link.save
        flash[:notice] = 'Link was successfully created.'
        format.html { redirect_to links_url(params[:username]) }
        format.xml  { render :xml => @link, :status => :created, 
          :location => link_url(params[:username], @link) }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @link.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /:username/links/1
  # PUT /:username/links/1.xml
  def update
    @link = Link.find(params[:id])
    respond_to do |format|
      if @link.update_attributes(params[:link])
        flash[:notice] = 'Link was successfully updated.'
        format.html { redirect_to links_url(current_user_id) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @link.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /:username/links/1
  # DELETE /:username/links/1.xml
  def destroy
    @link = Link.find(params[:id])
    @link.destroy

    respond_to do |format|
      format.html { redirect_to(links_url) }
      format.xml  { head :ok }
    end
  end
end
